==> igniteui-react-charts-18.6.0.tgz: package/esm5/lib/EaseOfMovementIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { EaseOfMovementIndicatorStrategy } from "./EaseOfMovementIndicatorStrategy";
import { markType } from "igniteui-react-core";
/**
 * @hidden
 */
var EaseOfMovementIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(EaseOfMovementIndicator, _super);
    function EaseOfMovementIndicator() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    EaseOfMovementIndicator.prototype.bc = function () {
        return new EaseOfMovementIndicator();
    };
    EaseOfMovementIndicator.prototype.get_y0 = function () {
        return new EaseOfMovementIndicatorStrategy();
    };
    Object.defineProperty(EaseOfMovementIndicator.prototype, "y0", {
        get: function () {
            return this.get_y0();
        },
        enumerable: false,
        configurable: true
    });
    EaseOfMovementIndicator.prototype.get_zd = function () {
        return EaseOfMovementIndicator.$;
    };
    Object.defineProperty(EaseOfMovementIndicator.prototype, "zd", {
        get: function () {
            return this.get_zd();
        },
        enumerable: false,
        configurable: true
    });
    EaseOfMovementIndicator.$t = markType(EaseOfMovementIndicator, 'EaseOfMovementIndicator', StrategyBasedIndicator.$);
    return EaseOfMovementIndicator;
}(StrategyBasedIndicator));
export { EaseOfMovementIndicator };

==> igniteui-react-charts-18.7.2.tgz: package/esm5/lib/EaseOfMovementIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { EaseOfMovementIndicatorStrategy } from "./EaseOfMovementIndicatorStrategy";
import { markType } from "igniteui-react-core";
/**
 * @hidden
 */
var EaseOfMovementIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(EaseOfMovementIndicator, _super);
    function EaseOfMovementIndicator() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    EaseOfMovementIndicator.prototype.bi = function () {
        return new EaseOfMovementIndicator();
    };
    EaseOfMovementIndicator.prototype.get_abn = function () {
        return new EaseOfMovementIndicatorStrategy();
    };
    Object.defineProperty(EaseOfMovementIndicator.prototype, "abn", {
        get: function () {
            return this.get_abn();
        },
        enumerable: false,
        configurable: true
    });
    EaseOfMovementIndicator.prototype.get_ab0 = function () {
        return EaseOfMovementIndicator.$;
    };
    Object.defineProperty(EaseOfMovementIndicator.prototype, "ab0", {
        get: function () {
            return this.get_ab0();
        },
        enumerable: false,
        configurable: true
    });
    EaseOfMovementIndicator.$t = markType(EaseOfMovementIndicator, 'EaseOfMovementIndicator', StrategyBasedIndicator.$);
    return EaseOfMovementIndicator;
}(StrategyBasedIndicator));
export { EaseOfMovementIndicator };
